<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_TW" version="2.0">
<context>
    <name>Badges</name>
    <message>
        <location filename="../qml/pages/Badges.qml" line="18"/>
        <source>BADGES</source>
        <translation>徽章</translation>
    </message>
</context>
<context>
    <name>Checkin</name>
    <message>
        <location filename="../qml/pages/Checkin.qml" line="18"/>
        <source>CHECK-IN DETAILS</source>
        <translation>打卡內容</translation>
    </message>
    <message>
        <location filename="../qml/pages/Checkin.qml" line="222"/>
        <source>TOTAL POINTS</source>
        <translation>總分</translation>
    </message>
    <message>
        <location filename="../qml/pages/Checkin.qml" line="260"/>
        <source>EARNED BADGES</source>
        <translation>得到的徽章</translation>
    </message>
    <message>
        <location filename="../qml/pages/Checkin.qml" line="282"/>
        <source>COMMENTS</source>
        <translation>留言</translation>
    </message>
</context>
<context>
    <name>CheckinDialog</name>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="22"/>
        <source>NEW CHECK-IN</source>
        <translation>新的打卡</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="48"/>
        <source>CHECK IN</source>
        <translation>打卡</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="57"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="100"/>
        <source>Whats on your mind?</source>
        <translation>在想什麼呢？</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="129"/>
        <source>Sharing options</source>
        <translation>分享選項</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="133"/>
        <source>Share with Friends</source>
        <translation>與朋友分享</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="141"/>
        <source>Post to Facebook</source>
        <translation>分享至 Facebook</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinDialog.qml" line="149"/>
        <source>Post to Twitter</source>
        <translation>分享至 Twitter</translation>
    </message>
</context>
<context>
    <name>CheckinHistory</name>
    <message>
        <location filename="../qml/pages/CheckinHistory.qml" line="24"/>
        <source>CHECK-IN HISTORY</source>
        <translation>打卡紀錄</translation>
    </message>
    <message>
        <location filename="../qml/pages/CheckinHistory.qml" line="64"/>
        <source>Load More</source>
        <translation>載入更多</translation>
    </message>
</context>
<context>
    <name>CommentDialog</name>
    <message>
        <location filename="../qml/components/CommentDialog.qml" line="26"/>
        <source>What is on your mind?</source>
        <translation>在想什麼呢？</translation>
    </message>
    <message>
        <location filename="../qml/components/CommentDialog.qml" line="38"/>
        <source>New awesome comment</source>
        <translation>新的留言</translation>
    </message>
    <message>
        <location filename="../qml/components/CommentDialog.qml" line="69"/>
        <source>Comment!</source>
        <translation>發文！</translation>
    </message>
    <message>
        <location filename="../qml/components/CommentDialog.qml" line="77"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>DebugSubmit</name>
    <message>
        <location filename="../qml/pages/DebugSubmit.qml" line="18"/>
        <source>DEBUG SUBMIT</source>
        <translation>除錯資料傳送</translation>
    </message>
    <message>
        <location filename="../qml/pages/DebugSubmit.qml" line="34"/>
        <source>Thank you for submit!&lt;br&gt;This will be implemented soon!</source>
        <translation>感謝你的回報！&lt;br&gt;我們會盡快搞定的！</translation>
    </message>
    <message>
        <location filename="../qml/pages/DebugSubmit.qml" line="53"/>
        <source>SUBMIT</source>
        <translation>送出</translation>
    </message>
    <message>
        <location filename="../qml/pages/DebugSubmit.qml" line="61"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
    <message>
        <location filename="../qml/pages/DebugSubmit.qml" line="92"/>
        <source>You can help me with Nelisquare development by submitting debug info.

The following information are going to be submitted:</source>
        <translation>你可以傳送除錯訊息來協助我開發 Nelisquare 。

下列的資訊將會被傳送：</translation>
    </message>
</context>
<context>
    <name>DebugWidget</name>
    <message>
        <location filename="../qml/components/DebugWidget.qml" line="14"/>
        <source>Unknown %1 event!</source>
        <translation>未知的 %1 事件！</translation>
    </message>
    <message>
        <location filename="../qml/components/DebugWidget.qml" line="47"/>
        <source>This event type is unknown.
You can help with resolution.</source>
        <translation>未知的事件型態。
你可以協助分析。</translation>
    </message>
</context>
<context>
    <name>FriendsFeed</name>
    <message>
        <location filename="../qml/pages/FriendsFeed.qml" line="43"/>
        <source>FRIENDS FEED</source>
        <translation>朋友動態</translation>
    </message>
    <message>
        <location filename="../qml/pages/FriendsFeed.qml" line="229"/>
        <source>RECENT</source>
        <translation>最新消息</translation>
    </message>
    <message>
        <location filename="../qml/pages/FriendsFeed.qml" line="242"/>
        <source>NEARBY</source>
        <translation>在我附近</translation>
    </message>
    <message>
        <location filename="../qml/pages/FriendsFeed.qml" line="263"/>
        <source>Load More</source>
        <translation>載入更多</translation>
    </message>
    <message>
        <location filename="../qml/pages/FriendsFeed.qml" line="410"/>
        <source>Sorry, Pages are not supported yet :(</source>
        <translation>抱歉，尚未支援這頁面 :(</translation>
    </message>
    <message>
        <location filename="../qml/pages/FriendsFeed.qml" line="480"/>
        <source>Sorry, no lists support yet :(</source>
        <translation>抱歉，尚未支援清單 :(</translation>
    </message>
</context>
<context>
    <name>LeaderBoard</name>
    <message>
        <location filename="../qml/pages/LeaderBoard.qml" line="19"/>
        <source>YOU ARE #%1</source>
        <translation>你是第 %1</translation>
    </message>
    <message>
        <location filename="../qml/pages/LeaderBoard.qml" line="63"/>
        <source>&lt;b&gt;%1 points&lt;/b&gt; %2 checkins</source>
        <translation>&lt;b&gt;%1 分&lt;/b&gt; %2 個打卡</translation>
    </message>
</context>
<context>
    <name>LikeBox</name>
    <message>
        <location filename="../qml/components/LikeBox.qml" line="33"/>
        <source>USER LIKES</source>
        <translation>按讚的使用者</translation>
    </message>
</context>
<context>
    <name>ListViewEx</name>
    <message>
        <location filename="../qml/components/ListViewEx.qml" line="9"/>
        <source>Pull and hold to refresh...</source>
        <translation>下拉即可更新⋯⋯</translation>
    </message>
    <message>
        <location filename="../qml/components/ListViewEx.qml" line="10"/>
        <source>Release to refresh...</source>
        <translation>釋放立即更新⋯⋯</translation>
    </message>
</context>
<context>
    <name>Login24sq</name>
    <message>
        <location filename="../qml/pages/Login24sq.qml" line="15"/>
        <source>Sign In to Foursquare</source>
        <translation>登入至 Foursquare</translation>
    </message>
    <message>
        <location filename="../qml/pages/Login24sq.qml" line="41"/>
        <source>Exit</source>
        <translation>離開</translation>
    </message>
    <message>
        <location filename="../qml/pages/Login24sq.qml" line="59"/>
        <source>Error connecting to Foursquare site</source>
        <translation>連線至 Foursquare 網站時錯誤</translation>
    </message>
</context>
<context>
    <name>Mayorships</name>
    <message>
        <location filename="../qml/pages/Mayorships.qml" line="19"/>
        <source>MAYORSHIPS</source>
        <translation>市長</translation>
    </message>
</context>
<context>
    <name>NotificationDialog</name>
    <message>
        <location filename="../qml/components/NotificationDialog.qml" line="36"/>
        <source>OK</source>
        <translation>確定</translation>
    </message>
</context>
<context>
    <name>Notifications</name>
    <message>
        <location filename="../qml/pages/Notifications.qml" line="24"/>
        <source>NOTIFICATIONS</source>
        <translation>通知</translation>
    </message>
    <message>
        <location filename="../qml/pages/Notifications.qml" line="51"/>
        <source>Mark all as read</source>
        <translation>全部標示為已讀</translation>
    </message>
    <message>
        <location filename="../qml/pages/Notifications.qml" line="61"/>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
</context>
<context>
    <name>PageWrapper</name>
    <message>
        <location filename="../qml/components/PageWrapper.qml" line="101"/>
        <source>Check updates</source>
        <translation>檢查更新</translation>
    </message>
    <message>
        <location filename="../qml/components/PageWrapper.qml" line="107"/>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
    <message>
        <location filename="../qml/components/PageWrapper.qml" line="113"/>
        <source>Exit</source>
        <translation>離開</translation>
    </message>
</context>
<context>
    <name>Photo</name>
    <message>
        <location filename="../qml/pages/Photo.qml" line="20"/>
        <source>PHOTO</source>
        <translation>相片</translation>
    </message>
    <message>
        <location filename="../qml/pages/Photo.qml" line="45"/>
        <source>You cannot save image until download is finished</source>
        <translation>在下載完成之前你還不能儲存影像</translation>
    </message>
    <message>
        <location filename="../qml/pages/Photo.qml" line="49"/>
        <source>Image saved to %1</source>
        <translation>影像已儲存至 %1</translation>
    </message>
    <message>
        <location filename="../qml/pages/Photo.qml" line="51"/>
        <source>Failed to save image</source>
        <translation>儲存影像失敗</translation>
    </message>
</context>
<context>
    <name>PhotoAdd</name>
    <message>
        <location filename="../qml/pages/PhotoAdd.qml" line="19"/>
        <source>Select photo for upload</source>
        <translation>選擇要上傳的相片</translation>
    </message>
    <message>
        <location filename="../qml/pages/PhotoAdd.qml" line="60"/>
        <source>Error uploading photo!&lt;br&gt;Photo size should be less than %1KB</source>
        <translation>相片上傳失敗！
相片大小應小於 %1 KB</translation>
    </message>
</context>
<context>
    <name>PhotoShareDialog</name>
    <message>
        <location filename="../qml/pages/PhotoShareDialog.qml" line="20"/>
        <source>PHOTO UPLOAD</source>
        <translation>上傳相片</translation>
    </message>
    <message>
        <location filename="../qml/pages/PhotoShareDialog.qml" line="36"/>
        <source>UPLOAD</source>
        <translation>上傳</translation>
    </message>
    <message>
        <location filename="../qml/pages/PhotoShareDialog.qml" line="91"/>
        <source>Sharing options</source>
        <translation>分享選項</translation>
    </message>
    <message>
        <location filename="../qml/pages/PhotoShareDialog.qml" line="95"/>
        <source>Public</source>
        <translation>公開</translation>
    </message>
    <message>
        <location filename="../qml/pages/PhotoShareDialog.qml" line="102"/>
        <source>Post to Facebook</source>
        <translation>分享至 Facebook</translation>
    </message>
    <message>
        <location filename="../qml/pages/PhotoShareDialog.qml" line="109"/>
        <source>Post to Twitter</source>
        <translation>分享至 Twitter</translation>
    </message>
    <message>
        <location filename="../qml/pages/PhotoShareDialog.qml" line="48"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>PhotosBox</name>
    <message>
        <location filename="../qml/components/PhotosBox.qml" line="8"/>
        <source>PHOTOS</source>
        <translation>相片</translation>
    </message>
</context>
<context>
    <name>PhotosGallery</name>
    <message>
        <location filename="../qml/pages/PhotosGallery.qml" line="13"/>
        <source>VENUE PHOTOS</source>
        <translation>地盤相片</translation>
    </message>
</context>
<context>
    <name>SettingSlider</name>
    <message>
        <location filename="../qml/components/SettingSlider.qml" line="50"/>
        <source>Off</source>
        <translation>關閉</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <location filename="../qml/pages/Settings.qml" line="13"/>
        <source>updating...</source>
        <translation>更新中⋯⋯</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="21"/>
        <source>SETTINGS</source>
        <translation>設定</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="55"/>
        <source>2012-2013 Basil Semuonov</source>
        <translation>2012-2013 Basil Semuonov</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="56"/>
        <source>Idea by Tommi Laukkanen</source>
        <translation>構想： Tommi Laukkanen</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="57"/>
        <source>Shout out to @knobtviker</source>
        <translation>感謝 @knobtviker</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="58"/>
        <source>Design by Kim Venetvirta</source>
        <translation>設計： Kim Venetvirta</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="59"/>
        <source>If any problems, tweet @basil_s</source>
        <translation>如果有任何問題，請發推特到 @basil_s</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="60"/>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="62"/>
        <source>Build</source>
        <translation>Build</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="64"/>
        <source>Powered by Foursquare</source>
        <translation>Powered by Foursquare</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="66"/>
        <source>Close</source>
        <translation>關閉</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="72"/>
        <location filename="../qml/pages/Settings.qml" line="117"/>
        <source>Reset settings</source>
        <translation>重設所有設定</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="73"/>
        <source>This action will erase all data including auth token, application settings and cache.</source>
        <translation>這動作將會清除所有資料，包括驗證、程式設定及快取。</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="74"/>
        <source>Yes, clear the data</source>
        <translation>是，清除資料</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="75"/>
        <source>No, thanks</source>
        <translation>不了</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="83"/>
        <source>Language</source>
        <translation>語言</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="111"/>
        <source>Notifications</source>
        <translation>通知</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="163"/>
        <source>UPDATES CHECK</source>
        <translation>檢查更新</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="188"/>
        <source>None</source>
        <translation>無</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="194"/>
        <source>Stable</source>
        <translation>正式版</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="199"/>
        <source>Beta</source>
        <translation>Beta</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="205"/>
        <source>Alpha</source>
        <translation>Alpha</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="211"/>
        <source>INTERVALS</source>
        <translation>時間週期</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="215"/>
        <source>GPS Unlock timeout</source>
        <translation>GPS 解鎖逾時時間</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="216"/>
        <source>Instant</source>
        <translation>立即</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="216"/>
        <source>%1 secs(s)</source>
        <translation>%1 秒</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="216"/>
        <location filename="../qml/pages/Settings.qml" line="225"/>
        <source>Disabled</source>
        <translation>停用</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="224"/>
        <source>Feed autoupdate time</source>
        <translation>動態消息自動更新時間</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="225"/>
        <source>Off</source>
        <translation>關閉</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="225"/>
        <source>%1 min(s)</source>
        <translation>%1 分</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="233"/>
        <source>PERMISSIONS</source>
        <translation>權限</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="236"/>
        <source>Allow use of Location Data</source>
        <translation>允許使用定位資料</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="244"/>
        <source>Always run in background</source>
        <translation>總是在背景執行</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="252"/>
        <source>Enable notifications</source>
        <translation>啟用通知</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="260"/>
        <source>Feed at Home screen</source>
        <translation>主畫面動態消息</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="268"/>
        <source>Push notifications</source>
        <translation>通知推播</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="319"/>
        <source>COLOR THEME</source>
        <translation>佈景主題</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="338"/>
        <source>Light</source>
        <translation>亮色系</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="347"/>
        <source>Dark</source>
        <translation>暗色系</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="356"/>
        <source>SCREEN ORIENTATION</source>
        <translation>螢幕轉向</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="378"/>
        <source>Auto</source>
        <translation>自動</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="384"/>
        <source>Landscape</source>
        <translation>橫放</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="389"/>
        <source>Portrait</source>
        <translation>直立</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="395"/>
        <source>STARTUP PAGE</source>
        <translation>起始頁面</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="417"/>
        <source>Feed</source>
        <translation>動態消息</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="423"/>
        <source>Venues</source>
        <translation>地盤</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="428"/>
        <source>Self</source>
        <translation>個人檔案</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="434"/>
        <source>LANGUAGE</source>
        <translation>語言</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="445"/>
        <source>MAP PROVIDER</source>
        <translation>圖資提供者</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="468"/>
        <source>Nokia</source>
        <translation>Nokia</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="474"/>
        <source>Google</source>
        <translation>Google</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="479"/>
        <source>OSM</source>
        <translation>OSM</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="497"/>
        <source>IMAGE LOADING</source>
        <translation>相片載入</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="516"/>
        <source>All</source>
        <translation>所有</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="521"/>
        <source>Cached</source>
        <translation>已快取的</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="527"/>
        <source>INTEGRATION WITH APPS</source>
        <translation>整合其他 App</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="533"/>
        <source>Download MOLO.ME</source>
        <translation>下載 MOLO.ME</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="552"/>
        <source>MOLO.ME Photos</source>
        <translation>MOLO.ME 的相片</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="572"/>
        <source>APPLICATION CACHE</source>
        <translation>程式快取</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="580"/>
        <source>Clear</source>
        <translation>清除</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="592"/>
        <source>Size: %1</source>
        <translation>大小： %1</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="598"/>
        <source>UI</source>
        <translation>介面</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="601"/>
        <source>Reload UI</source>
        <translation>重載介面</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="607"/>
        <source>AUTHENTICATION</source>
        <translation>驗證</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="610"/>
        <source>Reset authentication</source>
        <translation>重新驗證</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="631"/>
        <source>ACCESS RATE LIMIT</source>
        <translation>存取頻率限制</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="637"/>
        <source>API requests available: %1 / %2</source>
        <translation>可用 API 請求： %1 / %2</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="643"/>
        <source>You are low on X-RATE requests</source>
        <translation>你所剩的 X-RATE 請求次數不多</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="648"/>
        <source>DEBUG</source>
        <translation>除錯</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="651"/>
        <source>Enable debug</source>
        <translation>啟用除錯</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="665"/>
        <source>Options will be available soon</source>
        <translation>此功能會儘快開放</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="680"/>
        <source>General</source>
        <translation>一般</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="681"/>
        <source>Theme</source>
        <translation>佈景主題</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="682"/>
        <source>Service</source>
        <translation>服務</translation>
    </message>
    <message>
        <location filename="../qml/pages/Settings.qml" line="683"/>
        <source>Debug</source>
        <translation>除錯</translation>
    </message>
</context>
<context>
    <name>SpecialsList</name>
    <message>
        <location filename="../qml/components/SpecialsList.qml" line="13"/>
        <source>VENUE SPECIALS</source>
        <translation>專屬地盤</translation>
    </message>
    <message>
        <location filename="../qml/components/SpecialsList.qml" line="31"/>
        <source>Unlocked!</source>
        <translation>已解鎖！</translation>
    </message>
</context>
<context>
    <name>TipDialog</name>
    <message>
        <location filename="../qml/components/TipDialog.qml" line="40"/>
        <source>Write some cool tip here</source>
        <translation>在這新增些小提示吧</translation>
    </message>
    <message>
        <location filename="../qml/components/TipDialog.qml" line="71"/>
        <source>ADD</source>
        <translation>新增</translation>
    </message>
    <message>
        <location filename="../qml/components/TipDialog.qml" line="79"/>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>TipPage</name>
    <message>
        <location filename="../qml/pages/TipPage.qml" line="22"/>
        <source>Usefull tip</source>
        <translation>有用的提示</translation>
    </message>
    <message>
        <location filename="../qml/pages/TipPage.qml" line="148"/>
        <source>TIP PHOTO</source>
        <translation>相片提示</translation>
    </message>
    <message>
        <location filename="../qml/pages/TipPage.qml" line="170"/>
        <source>Save tip</source>
        <translation>儲存提示</translation>
    </message>
    <message>
        <location filename="../qml/pages/TipPage.qml" line="178"/>
        <source>Mark as done</source>
        <translation>標示已完成</translation>
    </message>
</context>
<context>
    <name>TipsList</name>
    <message>
        <location filename="../qml/pages/TipsList.qml" line="18"/>
        <source>TIPS LIST</source>
        <translation>提示列表</translation>
    </message>
</context>
<context>
    <name>UpdateDialog</name>
    <message>
        <location filename="../qml/components/UpdateDialog.qml" line="12"/>
        <source>New update available</source>
        <translation>有新的更新可用</translation>
    </message>
    <message>
        <location filename="../qml/components/UpdateDialog.qml" line="13"/>
        <source>Version: %1&lt;br&gt;Type: %2&lt;br&gt;Build: %3&lt;br&gt;&lt;br&gt;Changelog: &lt;br&gt;%4</source>
        <translation>Version: %1&lt;br&gt;Type: %2&lt;br&gt;Build: %3&lt;br&gt;&lt;br&gt;更新紀錄： &lt;br&gt;%4</translation>
    </message>
    <message>
        <location filename="../qml/components/UpdateDialog.qml" line="19"/>
        <source>Update!</source>
        <translation>更新！</translation>
    </message>
    <message>
        <location filename="../qml/components/UpdateDialog.qml" line="20"/>
        <source>No, thanks</source>
        <translation>不了</translation>
    </message>
</context>
<context>
    <name>User</name>
    <message>
        <location filename="../qml/pages/User.qml" line="60"/>
        <source>USER DETAILS</source>
        <translation>用戶資料</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="69"/>
        <source>Change avatar</source>
        <translation>更換大頭照</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="77"/>
        <source>User lists</source>
        <translation>使用者列表</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="85"/>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="91"/>
        <source>Exit</source>
        <translation>離開</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="303"/>
        <source>Add Friend</source>
        <translation>加為朋友</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="315"/>
        <source>Approve Friend</source>
        <translation>加入朋友</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="322"/>
        <source>Deny friend</source>
        <translation>拒絕邀請</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="334"/>
        <source>Remove Friend</source>
        <translation>移除朋友</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="347"/>
        <source>&lt;b&gt;SCORES&lt;/b&gt; (LAST 7 DAYS)</source>
        <translation>&lt;b&gt;分數&lt;/b&gt; （近七日內）</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="352"/>
        <source>BEST SCORE</source>
        <translation>最佳分數</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="410"/>
        <source>Badges</source>
        <translation>個徽章</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="445"/>
        <source>Checkins</source>
        <translation>個打卡</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="480"/>
        <source>Mayorships</source>
        <translation>個市長</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="515"/>
        <source>Friends</source>
        <translation>個朋友</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="550"/>
        <source>Photos</source>
        <translation>張相片</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="586"/>
        <source>Tips</source>
        <translation>個提示</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="602"/>
        <source>YOU ARE #%1</source>
        <translation>你是第 %1</translation>
    </message>
    <message>
        <location filename="../qml/pages/User.qml" line="627"/>
        <source>&lt;b&gt;%1 points&lt;/b&gt; %2 checkins</source>
        <translation>&lt;b&gt;%1 分&lt;/b&gt; %2 個打卡</translation>
    </message>
</context>
<context>
    <name>UsersList</name>
    <message>
        <location filename="../qml/pages/UsersList.qml" line="21"/>
        <source>Loading...</source>
        <translation>載入中...</translation>
    </message>
    <message>
        <location filename="../qml/pages/UsersList.qml" line="30"/>
        <source>USER FRIENDS</source>
        <translation>朋友</translation>
    </message>
    <message>
        <location filename="../qml/pages/UsersList.qml" line="33"/>
        <source>LIKERS LIST</source>
        <translation>按讚名單</translation>
    </message>
</context>
<context>
    <name>Venue</name>
    <message>
        <location filename="../qml/pages/Venue.qml" line="142"/>
        <source>VENUE PHOTOS</source>
        <translation>地盤相片</translation>
    </message>
    <message>
        <location filename="../qml/pages/Venue.qml" line="250"/>
        <source>CHECK-IN HERE!</source>
        <translation>在這打卡！</translation>
    </message>
    <message>
        <location filename="../qml/pages/Venue.qml" line="272"/>
        <source>Venue doesn&apos;t have mayor yet!</source>
        <translation>這裡還沒有市長！</translation>
    </message>
    <message>
        <location filename="../qml/pages/Venue.qml" line="273"/>
        <source>is the mayor.</source>
        <translation>是市長。</translation>
    </message>
    <message>
        <location filename="../qml/pages/Venue.qml" line="273"/>
        <source>It could be you!</source>
        <translation>還不快搶！</translation>
    </message>
    <message>
        <location filename="../qml/pages/Venue.qml" line="274"/>
        <source>%1 checkins</source>
        <translation>%1 打卡</translation>
    </message>
    <message>
        <location filename="../qml/pages/Venue.qml" line="317"/>
        <source>BEST TIPS</source>
        <translation>最佳提示</translation>
    </message>
</context>
<context>
    <name>VenueAdd</name>
    <message>
        <location filename="../qml/pages/VenueAdd.qml" line="32"/>
        <source>ADD NEW VENUE</source>
        <translation>新增地盤</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenueAdd.qml" line="74"/>
        <source>Select category</source>
        <translation>選擇類別</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenueAdd.qml" line="94"/>
        <source>Select sub-category</source>
        <translation>選擇副類別</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenueAdd.qml" line="131"/>
        <source>VENUE NAME</source>
        <translation>地盤名稱</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenueAdd.qml" line="136"/>
        <source>Venue name required</source>
        <translation>地盤名稱為必填</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenueAdd.qml" line="145"/>
        <source>VENUE ADDRESS</source>
        <translation>地盤地址</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenueAdd.qml" line="150"/>
        <source>Street address is optional</source>
        <translation>街名為選填</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenueAdd.qml" line="159"/>
        <source>VENUE CATEGORY</source>
        <translation>地盤類別</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenueAdd.qml" line="164"/>
        <source>Not selected</source>
        <translation>尚未選擇</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenueAdd.qml" line="165"/>
        <source>Tap to select category</source>
        <translation>點擊以選擇類別</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenueAdd.qml" line="172"/>
        <source>Venue categories are not loaded yet</source>
        <translation>地盤類別尚未載入</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenueAdd.qml" line="182"/>
        <source>VENUE LOCATION</source>
        <translation>地盤位置</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenueAdd.qml" line="209"/>
        <source>CREATE VENUE</source>
        <translation>新增地盤</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenueAdd.qml" line="212"/>
        <source>You should specify venue name</source>
        <translation>請指定地盤名稱</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenueAdd.qml" line="216"/>
        <source>You should select category</source>
        <translation>請選擇類別</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenueAdd.qml" line="220"/>
        <source>Can&apos;t get GPS position for venue</source>
        <translation>無法取得地盤的 GPS 位置</translation>
    </message>
</context>
<context>
    <name>VenueMap</name>
    <message>
        <location filename="../qml/pages/VenueMap.qml" line="213"/>
        <source>GET ROUTE</source>
        <translation>計算路線</translation>
    </message>
</context>
<context>
    <name>VenuesList</name>
    <message>
        <location filename="../qml/pages/VenuesList.qml" line="23"/>
        <source>NEARBY VENUES</source>
        <translation>附近的地盤</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenuesList.qml" line="38"/>
        <source>GPS signal is fuzzy, cannot get your location</source>
        <translation>GPS 訊號太微弱，無法取得你的位置</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenuesList.qml" line="125"/>
        <source>Locking GPS, please wait</source>
        <translation>搜尋 GPS 中，請稍候</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenuesList.qml" line="141"/>
        <source>Tap to search place...</source>
        <translation>點擊以搜尋地點⋯⋯</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenuesList.qml" line="157"/>
        <source>SEARCH</source>
        <translation>搜尋</translation>
    </message>
    <message>
        <location filename="../qml/pages/VenuesList.qml" line="198"/>
        <source>ADD NEW VENUE</source>
        <translation>新增地盤</translation>
    </message>
</context>
<context>
    <name>Welcome</name>
    <message>
        <location filename="../qml/pages/Welcome.qml" line="29"/>
        <source>Welcome!</source>
        <translation>歡迎！</translation>
    </message>
    <message>
        <location filename="../qml/pages/Welcome.qml" line="46"/>
        <source>Please, login with Foursquare!</source>
        <translation>請登入 Foursquare！</translation>
    </message>
    <message>
        <location filename="../qml/pages/Welcome.qml" line="53"/>
        <source>Login</source>
        <translation>登入</translation>
    </message>
    <message>
        <location filename="../qml/pages/Welcome.qml" line="67"/>
        <source>Foursquare privacy policy</source>
        <translation>Foursquare 隱私權政策</translation>
    </message>
    <message>
        <location filename="../qml/pages/Welcome.qml" line="81"/>
        <source>Nelisquare privacy policy</source>
        <translation>Nelisquare 隱私權政策</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../qml/main.qml" line="387"/>
        <source>Location data</source>
        <translation>定位資料</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="388"/>
        <source>Nelisquare requires use of user location data. Data is needed to make geo-location services work properly.</source>
        <translation>Nelisquare 必須使用使用者定位資料以確保定位服務正常工作。</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="389"/>
        <source>Allow</source>
        <translation>允許</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="390"/>
        <source>Deny</source>
        <translation>拒絕</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="402"/>
        <source>Push notifications</source>
        <translation>推送通知</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="403"/>
        <source>Incoming push notifications are not supported at this version and are disabled by default.&lt;br/&gt;&lt;br/&gt;You will be promted again when they will be available at future versions.</source>
        <translation>新訊息的推送通知在此版本尚未正式啟用&lt;br/&gt;&lt;br/&gt;當此功能於未來版本啟用時你將會得到通知。</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="407"/>
        <source>OK</source>
        <translation>確定</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="124"/>
        <source>Check updates</source>
        <translation>檢查更新</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="130"/>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
    <message>
        <location filename="../qml/main.qml" line="136"/>
        <source>Exit</source>
        <translation>離開</translation>
    </message>
</context>
</TS>